from typing import List


def add(i: int, j: int) -> int:
    """
    Add two numbers
    """


def subtract(i: int, j: int) -> int:
    """
    Subtract two numbers
    """


def equal_shares(voters: list[str],
                 projects: list[str],
                 cost: dict[str, float],
                 approvers_utilities: dict[str, list[tuple[str, int]]],
                 total_budget: float) -> list[str]:
    """
    Basic equal shares implementation
    """
